cgexplore.terms.TargetAngleRange
================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetAngleRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetAngleRange.yield_angles
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetAngleRange.type1
      ~TargetAngleRange.type2
      ~TargetAngleRange.type3
      ~TargetAngleRange.element1
      ~TargetAngleRange.element2
      ~TargetAngleRange.element3
      ~TargetAngleRange.angles
      ~TargetAngleRange.angle_ks
   
   